@@ -8,8 +8,16 @@ from collections import defaultdict
 
 
 # Main function to be called is DTW
-def DTW (x, y, radius=1, dist=None):
-    fastdtw(x, y, radius, dist)
+def DTW(x, y):
+    ''' 
+    DTW
+    
+    distance, path
+    ''' 
+    
+    
+    distance, path = fastdtw(x, y)
+    return distance, path
 
 
 
